@@ -1,43 +1,11 @@
-# -*- coding: utf-8 -*-
+# coding: utf-8
 
 """
-WikiCreole to HTML converter
-This program is an example of how the creole.py WikiCreole parser
-can be used.
+    WikiCreole to HTML converter
 
-Copyright (c) 2007, Radomir Dopieralski <creole@sheep.art.pl>
-:copyleft: 2008 by the PyLucid team, see AUTHORS for more details.
-
-    PyLucid Updates by the PyLucid team:
-        - Bugfixes and better html code style
-        - Add a passthrough for all django template blocktags
-        - Add a passthrough for html code lines
-
-All rights reserved.
-
-Redistribution and use in source and binary forms, with or without
-modification, are permitted provided that the following conditions
-are met:
-
- * Redistributions of source code must retain the above copyright
-   notice, this list of conditions and the following disclaimer.
-
- * Redistributions in binary form must reproduce the above copyright
-   notice, this list of conditions and the following disclaimer in
-   the documentation and/or other materials provided with the
-   distribution.
-
-THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
-FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
-TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
-PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
-LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
-NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
-SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+    @copyright: 2007 MoinMoin:RadomirDopieralski,
+                2008-2010 JensDiemer
+    @license: GNU GPL v3 or above, see LICENSE for details.
 """
 
 import sys, re, traceback
